#
# spec file for package tvtime
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tvtime
Version:        1.0.2
Release:        268.2
Summary:        High Quality Television Application
License:        GPL-2.0+
Group:          Hardware/TV
Url:            http://tvtime.net
Source:         %{name}-%{version}.tar.bz2
Patch0:         tvtime-gcc41.patch
Patch1:         tvtime-1.0.2-videoinput.patch
Patch2:         tvtime.linux-compiler.patch
Patch3:         tvtime-glibc.patch
# I haven't sent libpng15.patch upstream, because project from url
# seems to be dead
Patch4:         tvtime-libpng15.patch
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
tvtime is a high quality television application for use with video
capture cards.	tvtime processes the input from a capture card and
displays it on a computer monitor or projector.  Unlike other
television applications, tvtime focuses on high visual quality.

tvtime supports: * Deinterlaced output at a full interlaced rate of
   59.94 frames per second for NTSC source or 50 frames per second
   for PAL sources. This gives smoothness of motion and high visual
   quality.

* Multiple deinterlacing algorithms for finding the optimal mode for
   your video content and available processor speed.

* 16:9 aspect ratio mode for the highest available resolution when
   processing input from an external DVD player or digital satellite
   receiver.

* A super-slick on-screen display for the complete television
   experience, with a feature-rich menu system.

* 2-3 Pulldown detection for optimal quality viewing of film content
   from NTSC sources.

You can find more information at http://tvtime.net/.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
autoreconf -i -f
%ifarch %ix86
RPM_OPT_FLAGS="%{optflags} -mmmx"
export CXXFLAGS="-mmmx"
%endif
export CFLAGS="%{optflags}"
%configure --with-pic
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%suse_update_desktop_file -i net-tvtime AudioVideo TV
%find_lang %{name}

%files -f %{name}.lang
%defattr(-, root, root)
%doc NEWS AUTHORS COPYING INSTALL ChangeLog README docs/html
%doc data/COPYING*
%{_bindir}/*
%dir %{_sysconfdir}/tvtime
%config(noreplace) %{_sysconfdir}/tvtime/*
%{_datadir}/tvtime
%{_datadir}/applications/net-tvtime.desktop
%{_datadir}/icons/hicolor/
%{_datadir}/pixmaps/tvtime.*
%{_mandir}/*/*

%changelog
* Sat Nov  8 2014 crrodriguez@opensuse.org
- Run spec cleaner
- replace use of xorg-x11-devel by individual pkgconfig()
  buildrequires.
* Thu Aug 30 2012 pgajdos@suse.com
- package builds also against libpng15
  * tvtime-libpng15.patch
* Mon Feb 20 2012 coolo@suse.com
- add explicit buildrequire on xorg-x11-devel
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Jun  4 2009 coolo@suse.de
- fix build with new glibc
* Sun Feb 24 2008 crrodriguez@suse.de
- use find_lang macro to create a proper language list
* Mon Aug  6 2007 olh@suse.de
- remove inclusion of linux/compiler.h
* Tue Mar 13 2007 anschneider@suse.de
- tvtime-1.0.2-videoinput.patch:
  VIDIOC_DQBUF called without setting cur_buf.memory
* Mon Oct 16 2006 ro@suse.de
- remove DirectFB from BuildRequires (unused)
* Mon Jan 30 2006 hvogel@suse.de
- fix buildrequires again
* Fri Jan 27 2006 hvogel@suse.de
- add libpng-devel and freetype2-devel to buildrequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 hvogel@suse.de
- update to version 1.0.2
* Fri Jan 13 2006 hvogel@suse.de
- update to version 1.0.1
* Mon Oct 17 2005 hvogel@suse.de
- removed some extra qualifications to make gcc happy again
* Thu Jun 23 2005 hvogel@suse.de
- mark config file as noreplace
* Wed May 18 2005 hvogel@suse.de
- also use -mmmx for c++
* Mon May 16 2005 ro@suse.de
- add -mmmx on x86
* Mon May  9 2005 hvogel@suse.de
- Update to version 0.99
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Fri Nov  5 2004 hvogel@suse.de
- update to version 0.9.15
* Thu Oct  7 2004 hvogel@suse.de
- update version to 0.9.13
* Thu Jan 29 2004 hvogel@suse.de
- mark config files as config
- mark man pages as documentation
- use bzip2 for the source
* Thu Jan  8 2004 hvogel@suse.de
- remove localstatedir/fifogroup usage
- stop moving desktop file around
* Mon Dec  1 2003 hvogel@suse.de
- readd part of the non intel patch
* Wed Nov 26 2003 hvogel@suse.de
- update to version 0.9.12
* Fri Nov 14 2003 meissner@suse.de
- do not do Intel specific stuff on non-i386 (loading of
  windows dlls, ioperm() and inb()).
- 2 pointer accesses (and probably more) are not 64bit clean.
- fixed destdir patch.
* Thu Nov 13 2003 hvogel@suse.de
- dont build as root
* Mon Oct 13 2003 hvogel@suse.de
- Initial package version 0.9.10
